@@ -17,7 +17,7 @@ class Database(object):
         self.config = Config()
 
         self.db = QSqlDatabase.addDatabase('QSQLITE')
-        self.db.setDatabaseName('user.db')
+        self.db.setDatabaseName(self.config.user_db_file)
         self.db.open()
 
         if self.config.general['first-run']:
